@@ -1,8 +1,8 @@
 package Weed::FieldSet;
 
-use Weed 'X3DFieldSet : X3DArrayHash ()';
+use Weed 'X3DFieldSet : X3DArrayHash { }';
 
-our $VERSION = '0.006';
+our $VERSION = '0.001';
 
 use Weed::Tie::Field;
 
@@ -21,10 +21,8 @@ sub new {
 		$fields[$i] = $field;
 		$fields{$name} = $field;
 
-		# make this a real tied hash later
 		tie $tiedFields{$name}, 'Weed::Tie::Field', $field;
-		#44217; make perl know that this is a ref
-		scalar $tiedFields{$name};    #
+		scalar $tiedFields{$name};    # make perl know that this is a ref
 	}
 
 	my $this = $self->X3DArrayHash::new( \@fields, \%fields );
@@ -33,6 +31,16 @@ sub new {
 	return $this;
 }
 
+# sub getClone {
+# 	my $this = shift;
+# 	my $copy = $this->new( $this->getName );
+#
+# 	$$copy->{fields}->{$_}->setValue( $this->getField($_) )
+# 	  foreach map { $_->getName } $this->getFieldDefinitions;
+#
+# 	return $copy;
+# }
+
 sub getField : lvalue {
 	my ( $this, $name ) = @_;
 
@@ -83,7 +91,7 @@ sub toString {
 			$string .= X3DGenerator->indent;
 			$string .= $_->getName;
 			$string .= X3DGenerator->space;
-			$string .= $_;
+			$string .= $_->isa('SFString') ? sprintf X3DGenerator->STRING, $_ : $_;
 			$string .= X3DGenerator->tidy_break;
 		}
 		X3DGenerator->dec;
