@@ -1,9 +1,11 @@
 package Weed::FieldTypes::SFNode;
 
-our $VERSION = '0.016';
+our $VERSION = '0.009';
 
 use Weed 'SFNode : X3DField { NULL }';
 
+use Want ();
+
 use overload
   'int' => sub { $_[0]->getValue ? 1 : 0 },
   '0+'  => sub { $_[0]->getValue ? 1 : 0 },
@@ -13,43 +15,35 @@ use overload
 
   'eq' => sub { "$_[0]" eq $_[1] },
   'ne' => sub { "$_[0]" ne $_[1] },
+
+  #'@{}' => sub { $_[0]->getValue },
+  #'%{}' => sub { $_[0]->getValue },
   ;
 
-use Want ();
-
-sub AUTOLOAD : lvalue {    #X3DMessage->Debug( @_, our $AUTOLOAD );
+sub AUTOLOAD : lvalue {    #X3DMessage->Debug(@_);
 	my $this = shift;
 	my $name = substr our $AUTOLOAD, rindex( $AUTOLOAD, ':' ) + 1;
 
-	$this = $this->getValue;
-	X3DMessage->UnknownField( 1, $this, $AUTOLOAD ), return unless ref $this;
-
-	#X3DMessage->DirectOutputIsFALSE, return unless $this->{directOutput};
+	my $node = $this->getValue;
+	X3DMessage->UnknownField( 1, $this, $AUTOLOAD ) unless ref $node;
 
 	if ( Want::want('RVALUE') ) {
-		my $field = $this->getField($name);
+		my $field = $node->getField($name);
 		Want::rreturn $field if Want::want 'ARRAY';
-		Want::rreturn $field->getClone->getValue;
+		Want::rreturn $field->getClone;
 	}
 
 	if ( Want::want('ASSIGN') ) {
-		$this->getField($name)->setValue( Want::want('ASSIGN') );
+		$node->getField($name)->setValue( Want::want('ASSIGN') );
 		Want::lnoreturn;
 	}
 
-	if ( Want::want('CODE') ) {
-		my $value = $this->getField($name)->getClone->getValue;
-		return $value;
-	}
+	return $node->getFields->getField($name)
+	  if Want::want('REF');
 
-	return $this->getFields->getField( $name, $this ) if Want::want('REF');
-
-	$this->getFields->getTiedField( $name, $this )    # fr: += ++ ...
+	$node->getFields->getTiedField($name)
 }
 
-#sub new {  X3DMessage->Debug;
-#shift->X3DField::new(@_) }
-
 #sub getClone { $_[0]->new( $_[0]->getValue ) }
 
 sub getCopy {
@@ -63,7 +57,10 @@ sub setValue {
 	my ( $this, $value ) = @_;
 
 	my $node = $this->getValue;
-	$node->getParents->remove($this) if ref $node;
+	if ($node) {
+		$node->getParents->remove($this);
+		#$node->dispose;
+	}
 
 	$value = $value->getValue
 	  if UNIVERSAL::isa( $value, 'SFNode' );
@@ -82,15 +79,19 @@ sub setValue {
 		X3DMessage->ValueHasToBeAtLeastOfTypeX3DNode( 1, $this, $value );
 	}
 
-	$node->dispose if ref $node;
 	return;
 }
 
 sub toString { sprintf "%s", $_[0]->getValue || X3DGenerator->NULL }
 
-sub DESTROY {    #X3DMessage->Debug(undef, $_[0]->getId, $_[0]->getName);
+sub dispose {    #print " SFNode::dispose ", $_[0]->getName;
+	my ( $this ) = @_;
+
+	return;
+}
+
+sub DESTROY {
 	my $this = shift;
-	#print new X3DHash $this;
 	$this->setValue(undef);
 	return;
 }
