@@ -1,7 +1,7 @@
 package Weed::Parse::Concept;
 use Weed::Perl;
 
-our $VERSION = '0.01';
+our $VERSION = '0.009';
 
 use Carp (); $Carp::CarpLevel = 1;
 
@@ -62,6 +62,27 @@ sub conceptStatement {
 				Carp::croak "Expected '}'";
 			}
 
+		}
+		elsif ( $$string =~ m.$_week_hash.gc ) {
+
+			my $body = &body($string);
+
+			if ( $$string =~ m.$_close_brace.gc ) {
+
+				return {
+					typeName   => $name,
+					supertypes => $supertypes,
+					new        => sub {
+						bless Weed::Tie::WeakHash->new, shift;
+					},
+					body => $body,
+				};
+
+			}
+			else {
+				Carp::croak "Expected '}'";
+			}
+
 		}
 
 		elsif ( $$string =~ m.$_open_bracket.gc ) {
